@@ -7,7 +7,7 @@
 #  define KMM_MYMONEY_NO_EXPORT
 #else
 #  ifndef KMM_MYMONEY_EXPORT
-#    ifdef MAKE_KMM_MYMONEY_LIB
+#    ifdef kmm_mymoney_EXPORTS
         /* We are building this library */
 #      define KMM_MYMONEY_EXPORT __attribute__((visibility("default")))
 #    else
